summaryrefslogtreecommitdiffstats
path: root/IntelFrameworkPkg/Include
diff options
context:
space:
mode:
authorqhuang8 <qhuang8@6f19259b-4bc3-4df7-8a09-765794883524>2007-11-22 06:00:39 +0000
committerqhuang8 <qhuang8@6f19259b-4bc3-4df7-8a09-765794883524>2007-11-22 06:00:39 +0000
commit8a7d75b0625cffee0c67b85afe56763f93d86481 (patch)
tree45716a8f9a7655991c7982fc7b6dfdb86ca95847 /IntelFrameworkPkg/Include
parentd11013980ff815192ca3c280335ee67251302173 (diff)
downloadedk2-8a7d75b0625cffee0c67b85afe56763f93d86481.tar.gz
edk2-8a7d75b0625cffee0c67b85afe56763f93d86481.tar.bz2
edk2-8a7d75b0625cffee0c67b85afe56763f93d86481.zip
Clean up: update "EFI" to "UEFI" if applicable.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@4317 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'IntelFrameworkPkg/Include')
-rw-r--r--IntelFrameworkPkg/Include/Framework/DxeCis.h4
-rw-r--r--IntelFrameworkPkg/Include/Protocol/PciPlatform.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/IntelFrameworkPkg/Include/Protocol/PciPlatform.h b/IntelFrameworkPkg/Include/Protocol/PciPlatform.h
index 87a02889ee..2db71ebc14 100644
--- a/IntelFrameworkPkg/Include/Protocol/PciPlatform.h
+++ b/IntelFrameworkPkg/Include/Protocol/PciPlatform.h
@@ -143,7 +143,7 @@ EFI_STATUS
The GetPciRom() function gets the PCI device's option ROM from a platform-specific location.
The option ROM will be loaded into memory. This member function is used to return an image
that is packaged as a PCI 2.2 option ROM. The image may contain both legacy and EFI option
- ROMs. See the EFI 1.10 Specification for details. This member function can be used to return
+ ROMs. See the UEFI 2.0 Specification for details. This member function can be used to return
option ROM images for embedded controllers. Option ROMs for embedded controllers are typically
stored in platform-specific storage, and this member function can retrieve it from that storage
and return it to the PCI bus driver. The PCI bus driver will call this member function before
diff --git a/IntelFrameworkPkg/Include/Framework/DxeCis.h b/IntelFrameworkPkg/Include/Framework/DxeCis.h
index 9c5a28ea51..f86ba26e40 100644
--- a/IntelFrameworkPkg/Include/Framework/DxeCis.h
+++ b/IntelFrameworkPkg/Include/Framework/DxeCis.h
@@ -1,5 +1,5 @@
/** @file
- Include file that supportes Framework extension to the EFI 1.10 spec.
+ Include file that supportes Framework extension to the UEFI 2.0 spec.
This include file must only contain things defined in the Framework
specifications. If a code construct is defined in the Framework specification
@@ -66,7 +66,7 @@ typedef struct {
EFI_RESET_SYSTEM ResetSystem;
//
// Framework extension to EFI 1.10 runtime table
// It was moved to a protocol to not conflict with UEFI 2.0
//
EFI_REPORT_STATUS_CODE ReportStatusCode;
@@ -66,7 +66,7 @@ typedef struct {
EFI_RESET_SYSTEM ResetSystem;
//
- // Framework extension to EFI 1.10 runtime table
+ // Framework extension to UEFI 2.0 runtime table
// It was moved to a protocol to not conflict with UEFI 2.0
//